Flask et SSL
============
![category](développement)
![tag](python)

Flask est un framework web python qui permet aussi de créer un serveur web rapide.

Il est possible de travailler en mode sécurisé avec ce serveur en ajoutant un
contexte ssl. Il faudra auparavant installer ssl et créer les certificats

Création certificats
--------------------

Pour cela il faut utiliser la librairie openssl

```bash
apt-get install openssl
```

On peut maintenant créer les certificats

```bash
openssl genrsa -des3 -out server.orig.key 2048
openssl rsa -in server.orig.key -out server.key
openssl req -new -key server.key -out server.csr
openssl x509 -req -days 365 -in server.csr -signkey server.key -out server.crt
```

```note
Nous créons içi des certificats auto-signés ... la plupart des navigateurs
modernes vont crier aux scandales ... vous pouvez passer outre (puisqu'il s'agit de
votre certificat et que vous vous faites confiances) il faudrait utiliser
un tiers de confiance ... mais cela devient payant
```

Intégration de SSL dans Flask
-----------------------------

et voilà un exemple minimal

```python
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import ssl
from flask import Flask

app = Flask(__name__)

@app.route("/")
def hello():
    return "Hello World!"

context = ssl.SSLContext(ssl.PROTOCOL_TLSv1_2)
context.load_cert_chain('server.crt', 'server.key')
app.run(host='127.0.0.1',port=12344, ssl_context=context)```
